@@ -28,7 +28,7 @@ macro_rules! enable_protocol {
         if let Some(handler) = $node.protocols.$handler_type.get() {
             let (conn_returner, conn_retriever) = oneshot::channel();
 
-            handler.trigger(($conn, conn_returner)).await;
+            handler.trigger(($conn, conn_returner));
 
             match conn_retriever.await {
                 Ok(Ok(conn)) => conn,
@@ -318,7 +318,7 @@ impl Node {
             if self.is_connected(addr) {
                 let (sender, receiver) = oneshot::channel();
 
-                handler.trigger((addr, sender)).await;
+                handler.trigger((addr, sender));
                 let _ = receiver.await; // can't really fail
             }
         }
@@ -369,6 +369,11 @@ impl Node {
         self.connections.is_connected(addr)
     }
 
+    /// Checks if the node is currently setting up a connection with the provided address.
+    pub fn is_connecting(&self, addr: SocketAddr) -> bool {
+        self.connecting.lock().contains(&addr)
+    }
+
     /// Returns the number of active connections.
     pub fn num_connected(&self) -> usize {
         self.connections.num_connected()
