@@ -11,13 +11,13 @@ use pea2pea::{
 use std::{convert::TryInto, io, net::SocketAddr, time::Instant};
 
 const NUM_MESSAGES: usize = 10_000;
-const MSG_SIZE: usize = 64 * 1024;
+const MSG_SIZE: usize = 32 * 1024;
 
 static RANDOM_BYTES: Lazy<Bytes> = Lazy::new(|| {
     Bytes::from(
         (&mut SmallRng::from_entropy())
             .sample_iter(Standard)
-            .take(MSG_SIZE - 4)
+            .take(MSG_SIZE - 2)
             .collect::<Vec<_>>(),
     )
 });
@@ -43,10 +43,10 @@ impl Reading for Sink {
         let mut buf = [0u8; MSG_SIZE];
 
         let payload_len = {
-            if reader.read_exact(&mut buf[..4]).is_err() {
+            if reader.read_exact(&mut buf[..2]).is_err() {
                 return Ok(None);
             }
-            u32::from_le_bytes(buf[..4].try_into().unwrap()) as usize
+            u16::from_le_bytes(buf[..2].try_into().unwrap()) as usize
         };
 
         if reader.read_exact(&mut buf[..payload_len]).is_err() {
@@ -77,7 +77,7 @@ async fn run_bench_scenario(sender_count: usize) -> f64 {
     }
 
     let config = Config {
-        read_buffer_size: MSG_SIZE * 3,
+        read_buffer_size: MSG_SIZE * sender_count,
         max_connections: sender_count as u16,
         ..Default::default()
     };
@@ -103,6 +103,8 @@ async fn run_bench_scenario(sender_count: usize) -> f64 {
             for _ in 0..NUM_MESSAGES {
                 spammer
                     .send_direct_message(sink_addr, RANDOM_BYTES.clone())
+                    .unwrap()
+                    .await
                     .unwrap();
             }
         });
