@@ -37,6 +37,9 @@ async fn check_node_cleanups() {
     let persistent_node = common::MessagingNode::new("persistent").await;
     let persistent_addr = persistent_node.node().listening_addr().unwrap();
 
+    // measure the size of a node with no protocols enabled
+    let idle_node_size = (PEAK_ALLOC.current_usage() - initial_heap_use) / 1000;
+
     // enable all the protocols to check for any leaks there too
     persistent_node.enable_handshake().await;
     persistent_node.enable_reading().await;
@@ -46,11 +49,8 @@ async fn check_node_cleanups() {
     // register heap use after node setup
     let heap_after_node_setup = PEAK_ALLOC.current_usage();
 
-    // start keeping track of average heap use
-    let mut heap_sizes = Vec::with_capacity(NUM_CONNS);
-
-    // decrease the heap measurements in the loop by the helper vector's allocation
-    let mem_deduction = PEAK_ALLOC.current_usage() - heap_after_node_setup;
+    // start keeping track of the average heap use
+    let mut avg_heap_use = 0;
 
     // due to tokio channel internals, a small heap bump occurs after 32 calls to `mpsc::Sender::send`
     // if it wasn't for that, heap use after the 1st connection (i == 0) would be registered instead
@@ -79,6 +79,8 @@ async fn check_node_cleanups() {
 
         persistent_node
             .send_direct_message(temporary_addr, Bytes::from(&b"herp"[..]))
+            .unwrap()
+            .await
             .unwrap();
 
         temporary_node
@@ -93,40 +95,42 @@ async fn check_node_cleanups() {
         // drop the temporary node to fully relinquish its memory
         drop(temporary_node);
 
-        let current_heap_size = PEAK_ALLOC.current_usage() - mem_deduction;
+        // obtain and record current memory use
+        let current_heap_use = PEAK_ALLOC.current_usage();
 
         // register heap use once the 33rd connection is established and dropped
         if i == 32 {
-            heap_after_32_conns = current_heap_size;
+            heap_after_32_conns = current_heap_use;
         }
 
         // save current heap size to calculate average use later on
-        heap_sizes.push(current_heap_size);
+        avg_heap_use += current_heap_use;
     }
 
     // calculate avg heap use
-    let avg_heap_use = heap_sizes.iter().sum::<usize>() / heap_sizes.len();
-
-    // drop the vector of heap sizes so it doesn't affect further measurements
-    drop(heap_sizes);
+    let avg_heap_use = avg_heap_use / NUM_CONNS;
 
     // check final heap use and calculate heap growth
     let final_heap_use = PEAK_ALLOC.current_usage();
     let heap_growth = final_heap_use - heap_after_32_conns;
 
+    // calculate some helper values
+    let max_heap_use = PEAK_ALLOC.peak_usage() / 1000;
+    let final_heap_use_kb = final_heap_use / 1000;
+    let single_node_size = (heap_after_node_setup - initial_heap_use) / 1000;
+
     println!("---- heap use summary ----\n");
     println!("before node setup:     {}kB", initial_heap_use / 1000);
     println!("after node setup:      {}kB", heap_after_node_setup / 1000);
     println!("after 32 connections:  {}kB", heap_after_32_conns / 1000);
-    println!(
-        "after {} connections: {}kB",
-        NUM_CONNS,
-        final_heap_use / 1000
-    );
+    println!("after {} connections: {}kB", NUM_CONNS, final_heap_use_kb);
+    println!("average memory use:    {}kB", avg_heap_use / 1000);
+    println!("maximum memory use:    {}kB", max_heap_use);
+    println!();
+    println!("idle node size: {}kB", idle_node_size);
+    println!("full node size: {}kB", single_node_size);
+    println!("leaked memory:  {}B", heap_growth);
     println!();
-    println!("average use: {}kB", avg_heap_use / 1000);
-    println!("maximum use: {}kB", PEAK_ALLOC.peak_usage() / 1000);
-    println!("growth:      {}B", heap_growth);
 
     // regardless of the number of connections the node handles, its memory use shouldn't grow at all
     assert_eq!(heap_growth, 0);
